Description Usage Arguments Examples
Equation 19 of the paper
1 |
x |
Support of the probability density function. |
G |
Baseline cumulative distribution function. |
p_n |
Zero-truncated power series distribution. |
N |
Maximum number of sums of the external sum of Eq. 19 of the paper. |
K |
Maximum number of sums of the interior sum of Eq. 19 of the paper. |
alpha |
Parameter added by the proposed family. |
theta |
Parameter added by the proposed family. |
parallel |
If |
... |
Baseline distribution parameters. |
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 | # Implementing the Weibull distribution function (baseline). This function is
# used in the eq_19 function. Another baseline G can be passed and tested in
# eq_19.
cdf_w <- function(x, beta, lambda) {
1 - exp(-(lambda * x)^beta)
}
pdf_aprox <- function(x, alpha, theta, lambda, beta) {
eq_19(
x = x,
G = cdf_w,
p_n = pf_ztp,
N = 200L,
K = 100L,
alpha = alpha,
theta = theta,
beta = beta,
lambda = lambda
)
}
# True parameters
x = 1.28
alpha = 1.2
theta = 1.5
beta = 1.33
lambda = 2
# Checking theorical density and approximate density for a finite sum of Eq 19 of the paper
pdf_aprox(
x = x,
alpha = alpha,
theta = theta,
lambda = lambda,
beta = beta
)
pdf_theorical(
x = x,
alpha = alpha,
theta = theta,
beta = beta,
lambda = lambda
)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.